@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sample-mozilla.c,v 1.7 2004/12/30 22:45:17 chpe Exp $
+ *  $Id: sample-mozilla.c 1376 2006-09-13 19:01:42Z chpe $
  */
 
 #include "config.h"
@@ -32,7 +32,7 @@ G_MODULE_EXPORT GType register_module (GTypeModule *module);
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
-	LOG ("Registering EphySample2Extension")
+	LOG ("Registering EphySample2Extension");
 
 #ifdef ENABLE_NLS
        /* Initialise the i18n stuff */
